#!/usr/bin/tclsh
#
set filename "topology.tcl"
source $filename

#
set COMMON_CONFIG \
{
	#DocumentRoot /data/www/private/HTMLrequester

<Directory "/data/www/private/HTMLrequester/members">
Options Indexes MultiViews FollowSymLinks
        AuthType Basic
        AuthName "Member's Area"
        AuthFormAuthoritative On

        AuthFormMySQLHost localhost
        AuthFormMySQLUsername www-data
        AuthFormMySQLPassword www-data
        AuthFormMySQLDB members

        AuthFormMySQLTableSID sessions
        AuthFormMySQLTableGID uid_gid
        AuthFormMySQLTableTracking tracking

        AuthFormMySQLFieldUID uid
        AuthFormMySQLFieldGID gid
        AuthFormMySQLFieldDownloadSize download_size
        AuthFormMySQLFieldDownloadPath download_path
        AuthFormMySQLFieldDownloadDate download_date
        AuthFormMySQLFieldTimeout timeout_date
        AuthFormMySQLFieldIPAddress client_ip_address
        AuthFormMySQLFieldExpiration expiration_date

        AuthFormMySQLTableSIDCondition "`sid`=$sid1 AND `sid_dir`=$sid2 AND (`uid`=$uid OR `signature`='members')"

        AuthFormSessionTimeout 86400
        AuthFormSessionCookies On
        AuthFormSessionAutoRefresh -1
        AuthFormTrackingLifetime 86400

        AuthFormPageLogin /portal/HTMLrequester.html
        AuthFormPageExpired /portal/session_expired.html
        AuthFormLastPageKey go_back_to
        #AuthFormPageAutoRefresh
        #AuthFormPageNotAllowed

        #Require valid-user
        Require group 0 1 2
</Directory>

<Directory "/data/www/private/HTMLrequester/router_stage">

Options Indexes MultiViews FollowSymLinks
        AuthType Basic
        AuthName "Staging area"
        AuthFormAuthoritative On

        AuthFormMySQLHost localhost
        AuthFormMySQLUsername www-data
        AuthFormMySQLPassword www-data
        AuthFormMySQLDB members

        AuthFormMySQLTableSID sessions
        AuthFormMySQLTableGID uid_gid
        AuthFormMySQLTableTracking tracking

        AuthFormMySQLFieldUID uid
        AuthFormMySQLFieldGID gid
        AuthFormMySQLFieldDownloadSize download_size
        AuthFormMySQLFieldDownloadPath download_path
        AuthFormMySQLFieldDownloadDate download_date
        AuthFormMySQLFieldTimeout timeout_date
        AuthFormMySQLFieldIPAddress client_ip_address
        AuthFormMySQLFieldExpiration expiration_date

        AuthFormMySQLTableSIDCondition "`sid`=$sid1 AND `sid_dir`=$sid2 AND `uid`=$uid"

        AuthFormSessionTimeout 86400
        AuthFormSessionCookies Off
        AuthFormSessionAutoRefresh -1
        AuthFormTrackingLifetime 86400

	AuthFormPageLogin /portal/HTMLrequester.html
        AuthFormPageExpired /portal/session_expired.html
        AuthFormLastPageKey go_back_to
#        Require group 0 1 2
</Directory>

	ScriptAlias /cgi-bin/ /usr/lib/cgi-bin/
	<Directory "/usr/lib/cgi-bin">
		AllowOverride None
		Options +ExecCGI -MultiViews +SymLinksIfOwnerMatch
		Order allow,deny
		Allow from all
	</Directory>

	ErrorLog /var/log/apache2/error.log

	# Possible values include: debug, info, notice, warn, error, crit,
	# alert, emerg.
	LogLevel debug

	CustomLog /var/log/apache2/access.log combined

    Alias /doc/ "/usr/share/doc/"
    <Directory "/usr/share/doc/">
        Options Indexes MultiViews FollowSymLinks
        AllowOverride None
        Order deny,allow
        Deny from all
        Allow from 127.0.0.0/255.0.0.0 ::1/128
    </Directory>
</VirtualHost>

}



# generate the config
# old stuff next 4 lines
# puts "#\n# n4c-default.conf Configuration generated [clock format [clock seconds]]\n#"
# puts "<VirtualHost *:80>"
# puts "       ServerAdmin librarian@village.n4c.eu"
# puts "        ServerName [info hostname]"

puts "#"
puts "# n4c-default.conf Configuration generated [clock format [clock seconds]]\n#"
puts "#"
puts "MimeMagicFile /etc/apache2/magic"
puts "<VirtualHost *:80>"
puts "	    ServerAdmin $admin"
puts "	    ServerName [info hostname]"
puts ""
puts "	    DocumentRoot /data/www/statichtml"
puts "      ErrorDocument 404 /sorry.html"
puts ""
puts ""
puts "<Directory \"/data/www/statichtml\">"
puts "		Options FollowSymLinks"
puts "		AllowOverride None"
puts "</Directory>"
puts ""
puts "    Alias /mailsignup/ \"/data/apps/DTNmailex/bin/mailsignup.php\""
puts "<Directory \"/data/www/private/MAILaccounts\">"
puts "		Options FollowSymLinks"
puts "		AllowOverride None"
puts "</Directory>"
puts ""
puts "    Alias /portal/ \"/data/www/private/HTMLrequester/\""
puts $COMMON_CONFIG

puts ""
puts "<IfModule mod_ssl.c>"
puts "<VirtualHost *:443>"
puts "  ServerAdmin $admin"
puts "  ServerName [info hostname]"
puts "  DocumentRoot /data/www/statichtml"
puts "  SSLEngine on"
puts "  SSLCertificateFile \\"
puts "  /data/dtn/certs/apache/server.crt"
puts "  SSLCertificateKeyFile \\"
puts "  /data/dtn/certs/apache/server.key"
puts "<Directory \"/data/www/statichtml\">"
puts "          Options FollowSymLinks"
puts "          AllowOverride None"
puts "</Directory>"
puts ""
puts "Alias /mailsignup/ \"/data/apps/DTNmailex/bin/mailsignup.php\""
puts "<Directory \"/data/www/private/MAILaccounts\">"
puts "          Options FollowSymLinks"
puts "          AllowOverride None"
puts "</Directory>"
puts ""
puts "Alias /portal/ \"/data/www/private/HTMLrequester/\""
puts $COMMON_CONFIG
puts "</IfModule>"

puts "#"
puts "# n4c-default.conf for ROW "
puts "#"
puts "NameVirtualHost $rowip:80"
puts "<VirtualHost $rowip:80>"
puts "ReDirect 302 / http://village.n4c.eu/"
puts "</VirtualHost>"
puts "NameVirtualHost $rowip:443"
puts "<VirtualHost $rowip:443>"
puts "ReDirect 302 / http://village.n4c.eu/"
puts "</VirtualHost>"
