#!/usr/bin/tclsh
#
# Simple tcl script to generate a static topology of dtn links and
#
set addr(basil.dsg.cs.tcd.ie)   192.168.1.102
set addr(n4cgateway-1)          10.125.14.10
set addr(n4cgateway-2)          10.125.14.11
set addr(n4crouter-1)           10.125.14.12
set addr(n4crouter-2)           10.125.14.13
set addr(n4crouter-3)           10.125.14.14
set addr(n4crouter-4)           10.125.14.15
set addr(n4crouter-5)           10.125.14.16
set addr(n4cmule-1)             10.125.14.17
set addr(n4cmule-2)             10.125.14.18
set addr(n4cmule-3)             10.125.14.19
set addr(n4cmule-4)             10.125.14.20
set addr(n4cmule-5)             10.125.14.21
set mac(n4cmule-1)             00:0e:8e:1e:12:4a
set mac(n4cmule-2)             00:80:48:7e:72:aa
set mac(n4cmule-3)             00:80:48:7e:72:a9
set mac(n4cmule-4)             00:15:af:ee:da:fd
set mac(n4cmule-5)             00:15:af:ca:da:c1
set mac(n4cgateway-1)	       00:15:af:e5:5b:f1
set mac(n4cgateway-2)	       00:15:af:ca:ea:82

set localhost [lindex [split [info hostname] .] 0]
set ip $addr([lindex [split [info hostname] .] 0])
set domain \"village.n4c.eu\"
set type [lindex [split [info hostname] -] 0]
set subnet 10.125.14.0
set netmask 255.255.255.0
set broadcast 10.125.14.255
set r1 10.125.14.50
set r2 10.125.14.225
#
# Common config for all nodes
#
set COMMON_CONFIG \
{
ddns-update-style none;
default-lease-time 600;
max-lease-time 7200;
log-facility local7;
}
# generate the config
puts "#\n# DHCP Configuration generated [clock format [clock seconds]]\n#"
puts $COMMON_CONFIG
puts "option domain-name $domain;";
puts "option domain-name-servers [info hostname];"
puts "subnet $subnet netmask $netmask {"
puts "  range $r1 $r2;"
puts "  option domain-name-servers $ip;"
puts "  option domain-name $domain;"
puts "  option routers $ip;"
puts "  option broadcast-address $broadcast;"
puts "  default-lease-time 600;"
puts "  max-lease-time 7200;"
puts "}"

puts "host n4cmule-1 {"
puts "hardware ethernet $mac(n4cmule-1);"
puts "fixed-address $addr(n4cmule-1);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"

puts "host n4cmule-2 {"
puts "hardware ethernet $mac(n4cmule-2);"
puts "fixed-address $addr(n4cmule-2);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"

puts "host n4cmule-3 {"
puts "hardware ethernet $mac(n4cmule-3);"
puts "fixed-address $addr(n4cmule-3);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"

puts "host n4cmule-4 {"
puts "hardware ethernet $mac(n4cmule-4);"
puts "fixed-address $addr(n4cmule-4);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"

puts "host n4cmule-5 {"
puts "hardware ethernet $mac(n4cmule-5);"
puts "fixed-address $addr(n4cmule-5);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"

puts "host n4cgateway-1 {"
puts "hardware ethernet $mac(n4cgateway-1);"
puts "fixed-address $addr(n4cgateway-1);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"

puts "host n4cgateway-2 {"
puts "hardware ethernet $mac(n4cgateway-2);"
puts "fixed-address $addr(n4cgateway-2);"
puts "next-server $ip;"
puts "option domain-name $domain;"
puts "option domain-name-servers $ip;"
puts "option ntp-servers $ip;"
puts "}"
