#!/usr/bin/tclsh
#
set filename "topology.tcl"
source $filename

#
set COMMON_CONFIG_1 \
{
 set daemon  120           # check services at 2-minute intervals
     with start delay 60  # optional: delay the first check by 1-minutes
 set logfile syslog facility log_daemon                       
 set idfile /var/.monit.id
 set statefile /var/.monit.state
 set mailserver smtp.village.n4c.eu               # primary mailserver
 set eventqueue
     basedir /var/monit  # set the base directory where events will be stored
     slots 100           # optionaly limit the queue size
}
set COMMON_CONFIG_2 \
{
  check system 127.0.0.1
    if loadavg (1min) > 10 then alert
    if loadavg (5min) > 10 then alert
    if memory usage > 75% then alert
    if cpu usage (user) > 70% then alert
    if cpu usage (system) > 30% then alert
    if cpu usage (wait) > 20% then alert

  check directory data/dtn with path /data/dtn
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/dtn/payload with path /data/dtn/payload
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/dtn/storage with path /data/dtn/storage
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

 check directory data/dtn/storage/DTN with path /data/dtn/storage/DTN
    if failed permission 750 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/dtn/log with path /data/dtn/log
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

}

set ROUTER_CONFIG \
{
 check process pbmd with pidfile /var/run/pbmd.pid
   group server
   start program = "/etc/init.d/pbm start"
   stop program = "/etc/init.d/pbm stop"
   if 50 restarts within 50 cycles then timeout

 check file pbmd_file with path /var/log/syslog
   if timestamp > 65 minutes then alert # Have you seen "-- MARK --"?


 check process syslogd with pidfile /var/run/rsyslogd.pid
   group server
   start program = "/etc/init.d/rsyslog start"
   stop program = "/etc/init.d/rsyslog stop"
   if 50 restarts within 50 cycles then timeout

 check file syslogd_file with path /var/log/syslog
   if timestamp > 65 minutes then alert # Have you seen "-- MARK --"?

check process ntp with pidfile /var/run/ntpd.pid
   group net
   start program = "/etc/init.d/ntp start"
   stop  program = "/etc/init.d/ntp stop"
   if failed host 127.0.0.1 port 123 type udp then alert
   if 50 restarts within 50 cycles then timeout

 check process hostapd with pidfile /var/run/hostapd.pid
   group net
   start program = "/etc/init.d/hostapd start"
   stop program = "/etc/init.d/hostapd stop"
   if 50 restarts within 50 cycles then timeout
   depends on hostapd.conf

 check file hostapd.conf with path /etc/hostapd/hostapd.conf
   group net
   if failed checksum then unmonitor
   if failed permission 0600 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor


check process named with pidfile /var/run/named/named.pid
    group server
    start program = "/etc/init.d/bind9 start" with timeout 120 seconds
    stop program  = "/etc/init.d/bind9 stop"

check process dhcp3-server with pidfile /var/run/dhcp3-server/dhcpd.pid
    group server
    start program = "/etc/init.d/dhcp3-server start" with timeout 120 seconds
    stop program  = "/etc/init.d/dhcp3-server stop"

check process dovecot with pidfile /var/run/dovecot/master.pid
    group mail
    start program = "/etc/init.d/dovecot start" with timeout 120 seconds
    stop program  = "/etc/init.d/dovecot stop"

check process mysql with pidfile /var/run/mysqld/mysqld.pid
    group database
    start program = "/etc/init.d/mysql start" with timeout 120 seconds
    stop program  = "/etc/init.d/mysql stop"
    if failed host 127.0.0.1 port 3306 type tcp with timeout 20 seconds 
    then restart
    if 50 restarts within 50 cycles then timeout
    if failed unixsocket /var/run/mysqld/mysqld.sock then alert
    depends on mysqld 
    depends on mysql_rc 
    depends on data


 check file mysqld with path /usr/sbin/mysqld
   group database
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check file mysql_rc with path /etc/init.d/mysql
   group database
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check file resolv.conf with path /etc/resolv.conf
   group server
   if failed checksum then unmonitor
   if failed permission 644 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor


  check process apache2 
    with pidfile /var/run/apache2.pid
    group server
    start program = "/etc/init.d/apache2 start" with timeout 120 seconds
    stop program  = "/etc/init.d/apache2 stop"
    if cpu > 60% for 2 cycles then alert
    if cpu > 80% for 5 cycles then restart
    if totalmem > 200.0 MB for 5 cycles then restart
    if children > 250 then restart
    if loadavg(5min) greater than 10 for 8 cycles then restart
    if failed host village.n4c.eu port 80 protocol http
       and request "/index.html"
       then restart
    if failed host village.n4c.eu port 443 type tcpssl protocol http
       with timeout 20 seconds
       then restart
    if 3 restarts within 5 cycles then timeout
    depends on http.conf 
    depends on httpd.bin 
    depends on data

 check file http.conf 
    with path /etc/apache2/sites-available/n4c-default
     if changed checksum 
        then exec "/usr/sbin/apache2 graceful"

 check file httpd.bin 
     with path /usr/sbin/apache2
#     if failed checksum then exec "/watch/dog"
#        else if recovered then alert

  check process dtnmailsyncrd with pidfile /var/run/dtnmailsyncrd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailsyncr start"
    stop program = "/etc/init.d/dtnmailsyncr stop"
    depends on dtnd

  check process dtnmailsyncsd with pidfile /var/run/dtnmailsyncsd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailsyncs start"
    stop program = "/etc/init.d/dtnmailsyncs stop"
    depends on dtnd

  check process dtnmailsweepd with pidfile /var/run/dtnmailsweepd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailsweep start"
    stop program = "/etc/init.d/dtnmailsweep stop"
    depends on dtnd

  check process dtnmailackd with pidfile /var/run/dtnmailackd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailack start"
    stop program = "/etc/init.d/dtnmailack stop"
    depends on dtnd



 check process postfix with pidfile /var/spool/postfix/pid/master.pid
   group mail
   start program = "/etc/init.d/postfix start"
   stop  program = "/etc/init.d/postfix stop"
   if failed port 25 protocol smtp then restart
   if 50 restarts within 50 cycles then timeout
   depends on postfix_rc 
    depends on data


 check file postfix_rc with path /etc/init.d/postfix
   group mail
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor


  check process addaccount with pidfile /var/run/addaccount.php.pid
    group dtnmail
    start program = "/etc/init.d/addaccount start"
    stop program = "/etc/init.d/addaccount stop"
    depends on dtnd

 check process ssh with pidfile /var/run/sshd.pid
   start program  "/etc/init.d/ssh start"
   stop program  "/etc/init.d/ssh stop"
   if failed port 22 protocol ssh then restart
   if 50 restarts within 50 cycles then timeout

check process squid with pidfile /var/run/squid.pid
   group www
   start program = "/etc/init.d/squid start"
   stop  program = "/etc/init.d/squid stop"
   if failed host 127.0.0.1 port 8080  then restart
   if 50 restarts within 50 cycles then timeout
   depends on squid_bin 
    depends on squid_rc 
    depends on apache2 
    depends on data

 check file squid_bin with path /usr/sbin/squid
   group www
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check file squid_rc with path /etc/init.d/squid
   group www
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check process dtnd with pidfile /var/run/dtnd.pid
    group server
    start program = "/etc/init.d/dtn start" with timeout 120 seconds
    stop program  = "/etc/init.d/dtn stop"
    if cpu > 60% for 2 cycles then alert
    if cpu > 80% for 5 cycles then restart
    if totalmem > 200.0 MB for 5 cycles then restart
    if children > 250 then restart
    if loadavg(5min) greater than 10 for 8 cycles then restart
    if failed host 127.0.0.1 port 5050  then restart
# if 50 restarts within 50 cycles then exec "/foo/bar"
    depends on data 
    depends on root

  check directory data/dtn/mailaccounts with path /data/dtn/mailaccounts
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor

  check directory data/apps with path /data/apps
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/www with path /data/www
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor

  check directory data/dtn/cache with path /data/dtn/cache
    if failed permission 755 then unmonitor
    if failed uid proxy then unmonitor
    if failed gid proxy then unmonitor

  check directory data/dtn/certs with path /data/dtn/certs
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/dtn/mail with path /data/dtn/mail
    if failed permission 755 then unmonitor
    if failed uid mailowner then unmonitor
    if failed gid mailowner then unmonitor
  check directory data/www/private/HTMLrequester with path /data/www/private/HTMLrequester
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor

  check directory data/www/statichtml with path /data/www/statichtml
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor


#
#  check file database with path /data/mydatabase.db
#    if failed permission 700 then alert
#    if failed uid data then alert
#    if failed gid data then alert
#    if timestamp > 15 minutes then alert
#    if size > 100 MB then exec "/my/cleanup/script" as uid dba and gid dba

  check process dtnN4Cmiddleware with pidfile /var/run/dtnN4Cmiddleware.pid
    group middleware
    start program = "/etc/init.d/dtnN4Cmiddle start" with timeout 90 seconds
    stop program  = "/etc/init.d/dtnN4Cmiddle stop"
    if failed host 127.0.0.1 port 9090  then restart
    depends on dtnd 
    depends on apache2

  check process dtnN4Crecv with pidfile /var/run/dtnN4Crecv.pid
    group middleware
    start program = "/etc/init.d/dtnN4Crecv start" with timeout 90 seconds
    stop program  = "/etc/init.d/dtnN4Crecv stop"
    depends on dtnd 
    depends on apache2

  check process pushrecv with pidfile /var/run/pushrecv.pid
    group middleware
    start program = "/etc/init.d/pushrecv start" with timeout 90 seconds
    stop program  = "/etc/init.d/pushrecv stop"
    depends on dtnd
#    
#    
## Check filesystem permissions, uid, gid, space and inode usage. Other services,
## such as databases, may depend on this resource and an automatically graceful
## stop may be cascaded to them before the filesystem will become full and data
## lost.
#
  check filesystem data with path /dev/mmcblk0p1
    start program  = "/bin/mount /data"
    stop program  = "/bin/umount /data"
    if failed permission 0660 then unmonitor
    if failed uid 0 then unmonitor
    if failed gid 6 then unmonitor
    if space usage > 60% for 5 times within 15 cycles then alert
    if space usage > 80% for 5 times within 15 cycles then alert
    if space usage > 99% then stop
    if inode usage > 90000 then alert
    if inode usage > 99% then stop
    group server

check filesystem root with path /dev/sda1
    start program  = "/bin/mount /"
    stop program  = "/bin/umount /"
    if failed permission 0660 then unmonitor
    if failed uid root then unmonitor
    if failed gid 6 then unmonitor
    if space usage > 80% for 5 times within 15 cycles then alert
    if space usage > 85% for 5 times within 15 cycles then exec "/data/dtn/scripts/mvlog.sh"

    if space usage > 99% then stop
    if inode usage > 90000 then alert
    if inode usage > 99% then stop
    group server

}

set GATEWAY_CONFIG_BASIC \
{
 check process syslogd with pidfile /var/run/rsyslogd.pid
   start program = "/etc/init.d/rsyslog start"
   stop program = "/etc/init.d/rsyslog stop"
   if 50 restarts within 50 cycles then timeout

 check file syslogd_file with path /var/log/syslog
   if timestamp > 65 minutes then alert # Have you seen "-- MARK --"?

check process ntp with pidfile /var/run/ntpd.pid
   start program = "/etc/init.d/ntp start"
   stop  program = "/etc/init.d/ntp stop"
   if failed host 127.0.0.1 port 123 type udp then alert
   if 50 restarts within 50 cycles then timeout

 check process dtnd with pidfile /var/run/dtnd.pid
    start program = "/etc/init.d/dtn start" with timeout 120 seconds
    stop program  = "/etc/init.d/dtn stop"
    if failed host 127.0.0.1 port 5050  then restart
    group server

  check filesystem data with path /dev/mmcblk0p1
    start program  = "/bin/mount /data"
    stop program  = "/bin/umount /data"
    if failed permission 0660 then unmonitor
    if failed uid root then unmonitor
    if failed gid disk then unmonitor
    if space usage > 80% for 5 times within 15 cycles then alert
    if space usage > 99% then stop
    if inode usage > 90000 then alert
    if inode usage > 99% then stop
    group server


check filesystem root with path /dev/sda1
    start program  = "/bin/mount /"
    stop program  = "/bin/umount /"
    if failed permission 0660 then unmonitor
    if failed uid 0 then unmonitor
    if failed gid 6 then unmonitor
    if space usage > 80% for 5 times within 15 cycles then alert
    if space usage > 99% then stop
    if inode usage > 90000 then alert
    if inode usage > 99% then stop
    group server

}

set GATEWAY_ROUTER_CONFIG \
{
 check process syslogd with pidfile /var/run/rsyslogd.pid
   group server
   start program = "/etc/init.d/rsyslog start"
   stop program = "/etc/init.d/rsyslog stop"
   if 50 restarts within 50 cycles then timeout

 check file syslogd_file with path /var/log/syslog
   if timestamp > 65 minutes then alert # Have you seen "-- MARK --"?

check process ntp with pidfile /var/run/ntpd.pid
   group net
   start program = "/etc/init.d/ntp start"
   stop  program = "/etc/init.d/ntp stop"
   if failed host 127.0.0.1 port 123 type udp then alert
   if 50 restarts within 50 cycles then timeout

check process named with pidfile /var/run/named/named.pid
    group server
    start program = "/etc/init.d/bind9 start" with timeout 120 seconds
    stop program  = "/etc/init.d/bind9 stop"

check process dovecot with pidfile /var/run/dovecot/master.pid
    group mail
    start program = "/etc/init.d/dovecot start" with timeout 120 seconds
    stop program  = "/etc/init.d/dovecot stop"


check process mysql with pidfile /var/run/mysqld/mysqld.pid
    group database
    start program = "/etc/init.d/mysql start" with timeout 120 seconds
    stop program  = "/etc/init.d/mysql stop"
    if failed host 127.0.0.1 port 3306 type tcp with timeout 20 seconds 
    then restart
    if 50 restarts within 50 cycles then timeout
    if failed unixsocket /var/run/mysqld/mysqld.sock then alert
    depends on mysqld 
    depends on mysql_rc 
    depends on data


 check file mysqld with path /usr/sbin/mysqld
   group database
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check file mysql_rc with path /etc/init.d/mysql
   group database
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check file resolv.conf with path /etc/resolv.conf
   group server
   if failed checksum then unmonitor
   if failed permission 644 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor


  check process apache2 
    with pidfile /var/run/apache2.pid
    group server
    start program = "/etc/init.d/apache2 start" with timeout 120 seconds
    stop program  = "/etc/init.d/apache2 stop"
    if cpu > 60% for 2 cycles then alert
    if cpu > 80% for 5 cycles then restart
    if totalmem > 200.0 MB for 5 cycles then restart
    if children > 250 then restart
    if loadavg(5min) greater than 10 for 8 cycles then restart
    if failed host village.n4c.eu port 80 protocol http
       and request "/index.html"
       then restart
    if failed host village.n4c.eu port 443 type tcpssl protocol http
       with timeout 20 seconds
       then restart
    if 3 restarts within 5 cycles then timeout
    depends on http.conf 
    depends on httpd.bin 
    depends on data

 check file http.conf 
    with path /etc/apache2/sites-available/n4c-default
     if changed checksum 
        then exec "/usr/sbin/apache2 graceful"

 check file httpd.bin 
     with path /usr/sbin/apache2
#     if failed checksum then exec "/watch/dog"
#        else if recovered then alert

  check process dtnmailsyncrd with pidfile /var/run/dtnmailsyncrd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailsyncr start"
    stop program = "/etc/init.d/dtnmailsyncr stop"
    depends on dtnd

  check process dtnmailsyncsd with pidfile /var/run/dtnmailsyncsd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailsyncs start"
    stop program = "/etc/init.d/dtnmailsyncs stop"
    depends on dtnd

  check process dtnmailsweepd with pidfile /var/run/dtnmailsweepd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailsweep start"
    stop program = "/etc/init.d/dtnmailsweep stop"
    depends on dtnd

  check process dtnmailackd with pidfile /var/run/dtnmailackd.pid
    group dtnmail
    start program = "/etc/init.d/dtnmailack start"
    stop program = "/etc/init.d/dtnmailack stop"
    depends on dtnd



 check process postfix with pidfile /var/spool/postfix/pid/master.pid
   group mail
   start program = "/etc/init.d/postfix start"
   stop  program = "/etc/init.d/postfix stop"
   if failed port 25 protocol smtp then restart
   if 50 restarts within 50 cycles then timeout
   depends on postfix_rc 
    depends on data


 check file postfix_rc with path /etc/init.d/postfix
   group mail
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor


  check process addaccount with pidfile /var/run/addaccount.php.pid
    group dtnmail
    start program = "/etc/init.d/addaccount start"
    stop program = "/etc/init.d/addaccount stop"
    depends on dtnd

 check process ssh with pidfile /var/run/sshd.pid
   start program  "/etc/init.d/ssh start"
   stop program  "/etc/init.d/ssh stop"
   if failed port 22 protocol ssh then restart
   if 50 restarts within 50 cycles then timeout

check process squid with pidfile /var/run/squid.pid
   group www
   start program = "/etc/init.d/squid start"
   stop  program = "/etc/init.d/squid stop"
   if failed host 127.0.0.1 port 8080  then restart
   if 50 restarts within 50 cycles then timeout
   depends on squid_bin 
    depends on squid_rc 
    depends on apache2 
    depends on data

 check file squid_bin with path /usr/sbin/squid
   group www
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check file squid_rc with path /etc/init.d/squid
   group www
   if failed checksum then unmonitor
   if failed permission 755 then unmonitor
   if failed uid root then unmonitor
   if failed gid root then unmonitor

 check process dtnd with pidfile /var/run/dtnd.pid
    group server
    start program = "/etc/init.d/dtn start" with timeout 120 seconds
    stop program  = "/etc/init.d/dtn stop"
    if cpu > 60% for 2 cycles then alert
    if cpu > 80% for 5 cycles then restart
    if totalmem > 200.0 MB for 5 cycles then restart
    if children > 250 then restart
    if loadavg(5min) greater than 10 for 8 cycles then restart
    if failed host 127.0.0.1 port 5050  then restart
# if 50 restarts within 50 cycles then exec "/foo/bar"
    depends on data 
    depends on root

  check directory data/dtn/mailaccounts with path /data/dtn/mailaccounts
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor

  check directory data/apps with path /data/apps
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/www with path /data/www
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor

  check directory data/dtn/cache with path /data/dtn/cache
    if failed permission 755 then unmonitor
    if failed uid proxy then unmonitor
    if failed gid proxy then unmonitor

  check directory data/dtn/certs with path /data/dtn/certs
    if failed permission 755 then unmonitor
    if failed uid dtnuser then unmonitor
    if failed gid dtnuser then unmonitor

  check directory data/dtn/mail with path /data/dtn/mail
    if failed permission 755 then unmonitor
    if failed uid mailowner then unmonitor
    if failed gid mailowner then unmonitor
  check directory data/www/private/HTMLrequester with path /data/www/private/HTMLrequester
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor

  check directory data/www/statichtml with path /data/www/statichtml
    if failed permission 755 then unmonitor
    if failed uid www-data then unmonitor
    if failed gid www-data then unmonitor



  check process dtnN4Cmiddleware with pidfile /var/run/dtnN4Cmiddleware.pid
    group middleware
    start program = "/etc/init.d/dtnN4Cmiddle start" with timeout 90 seconds
    stop program  = "/etc/init.d/dtnN4Cmiddle stop"
    if failed host 127.0.0.1 port 9090  then restart
    depends on dtnd 
    depends on apache2

  check process dtnN4Crecv with pidfile /var/run/dtnN4Crecv.pid
    group middleware
    start program = "/etc/init.d/dtnN4Crecv start" with timeout 90 seconds
    stop program  = "/etc/init.d/dtnN4Crecv stop"
    depends on dtnd 
    depends on apache2

  check process pushrecv with pidfile /var/run/pushrecv.pid
    group middleware
    start program = "/etc/init.d/pushrecv start" with timeout 90 seconds
    stop program  = "/etc/init.d/pushrecv stop"
    depends on dtnd
#    
#    
## Check filesystem permissions, uid, gid, space and inode usage. Other services,
## such as databases, may depend on this resource and an automatically graceful
## stop may be cascaded to them before the filesystem will become full and data
## lost.
#
check filesystem root with path /dev/sda1
    start program  = "/bin/mount /"
    stop program  = "/bin/umount /"
    if failed permission 0660 then unmonitor
    if failed uid root then unmonitor
    if failed gid 6 then unmonitor
    if space usage > 80% for 5 times within 15 cycles then alert
    if space usage > 85% for 5 times within 15 cycles then exec "/data/dtn/scripts/mvlog.sh"

    if space usage > 99% then stop
    if inode usage > 90000 then alert
    if inode usage > 99% then stop
    group server

}

set MULE_CONFIG \
{
  check process dtnd with pidfile /var/run/dtnd.pid
    start program = "/etc/init.d/dtn start" with timeout 120 seconds
    stop program  = "/etc/init.d/dtn stop"
    if cpu > 60% for 2 cycles then alert
    if cpu > 80% for 5 cycles then restart
    if totalmem > 200.0 MB for 5 cycles then restart
    if children > 250 then restart
    if loadavg(5min) greater than 10 for 8 cycles then restart
    if failed host 127.0.0.1 port 5050  then restart

#
}

# generate the config
puts "#\n# Configuration generated [clock format [clock seconds]]\n#"
if {$type == "n4crouter"} {
    puts $COMMON_CONFIG_1
    puts "set mail-format {"
    puts "  from: monit@$localhost"
    puts "subject: \$SERVICE \$EVENT at \$DATE"
    puts "message: Monit \$ACTION \$SERVICE at \$DATE on \$HOST: \$DESCRIPTION."
    puts "}#"
    puts "set alert monit@village.n4c.eu                       # receive all alerts"
    puts "set httpd port 2812"
    puts "allow 127.0.0.1"
    puts "allow 10.125.14.0/255.255.255.0"
    puts "allow admin:$password"
    puts $COMMON_CONFIG_2
    puts $ROUTER_CONFIG
    } elseif {$type == "n4cgateway"} {
	if {$gwtype == "gateway-basic"} {
	    puts $COMMON_CONFIG_1
	    puts "set mail-format {"
	    puts "  from: monit@$localhost"
	    puts "subject: \$SERVICE \$EVENT at \$DATE"
	    puts "message: Monit \$ACTION \$SERVICE at \$DATE on \$HOST: \$DESCRIPTION."
	    puts "}#"
	    puts "set alert monit@village.n4c.eu                       # receive all alerts"
	    puts "set httpd port 2812"
	    puts "allow 127.0.0.1"
	    puts "allow 10.125.14.0/255.255.255.0"
	    puts "allow admin:$password"
	    puts $COMMON_CONFIG_2
	    puts $GATEWAY_BASIC_CONFIG
	} elseif {$gwtype == "gateway-router"} {
	    puts $COMMON_CONFIG_1
	    puts "set mail-format {"
	    puts "  from: monit@$localhost"
	    puts "subject: \$SERVICE \$EVENT at \$DATE"
	    puts "message: Monit \$ACTION \$SERVICE at \$DATE on \$HOST: \$DESCRIPTION."
	    puts "}#"
	    puts "set alert monit@village.n4c.eu                       # receive all alerts"
	    puts "set httpd port 2812"
	    puts "allow 127.0.0.1"
	    puts "allow 10.125.14.0/255.255.255.0"
	    puts "allow admin:$password"
	    puts $COMMON_CONFIG_2
	    puts $GATEWAY_ROUTER_CONFIG
            puts "check filesystem data with path /dev/sdb1"
            puts "   start program  = \"/bin/mount /data\""
            puts "   stop program  = \"/bin/umount /data\""
            puts "  if failed permission 0660 then unmonitor"
            puts "  if failed uid 0 then unmonitor"
            puts "  if failed gid 6 then unmonitor"
            puts "  if space usage > 60% for 5 times within 15 cycles then alert"
            puts "  if space usage > 80% for 5 times within 15 cycles then alert"
            puts "  if space usage > 99% then stop"
            puts "  if inode usage > 90000 then alert"
            puts "  if inode usage > 99% then stop"
            puts "  group server"

	}
    } elseif {$type == "n4cmule"} {
	if {$platform == "WRAP"} {
	puts $COMMON_CONFIG_1
	puts "set mail-format {"
	puts "  from: monit@$localhost"
	puts "subject: \$SERVICE \$EVENT at \$DATE"
	puts "message: Monit \$ACTION \$SERVICE at \$DATE on \$HOST: \$DESCRIPTION."
	puts "}#"
	puts "set alert monit@village.n4c.eu                       # receive all alerts"
	puts "set httpd port 2812"
	puts "allow 127.0.0.1"
	puts "allow 10.125.14.0/255.255.255.0"
	puts "allow admin:$password"
	puts $COMMON_CONFIG_2
	puts $MULE_CONFIG
	puts "check file dtn.conf with path /etc/dtn.conf"
	puts "check host $localhost with address village.n4c.eu"
	puts "      start program  = \"/etc/init.d/wifi start\""
	puts "      stop program  = \"/etc/init.d/wifi stop\""
	puts "  if failed icmp type echo count 3 with timeout 3 seconds then start"
	puts "check process dropbear with pidfile \"/var/run/dropbear.1.pid\""
	puts "start program = \"/etc/init.d/dropbear start\""
	puts "stop program = \"/etc/init.d/dropbear stop\""
	puts "if failed port 22 then restart"
	puts "check filesystem data with path /dev/sda3"
	puts "start program  = \"/bin/mount /data\""
	puts "stop program  = \"/bin/umount /data\""
	puts "if failed permission 0644 then unmonitor"
	puts "if failed uid root then unmonitor"
        puts "if failed gid root then unmonitor"
	puts "if space usage > 60% for 5 times within 15 cycles then alert"
	puts "if space usage > 80% for 5 times within 15 cycles then alert"
	puts "if space usage > 99% then stop"
	puts "if inode usage > 90000 then alert"
	puts "if inode usage > 99% then stop"
	puts "group server"
	} elseif {$platform == "eeepc"} {
	        puts $COMMON_CONFIG_1
		puts "set mail-format {"
		puts "  from: monit@$localhost"
		puts "subject: \$SERVICE \$EVENT at \$DATE"
		puts "message: Monit \$ACTION \$SERVICE at \$DATE on \$HOST: \$DESCRIPTION."
		puts "}#"
		puts "set alert monit@village.n4c.eu                       # receive all alerts"
		puts "set httpd port 2812"
		puts "allow 127.0.0.1"
		puts "allow 10.125.14.0/255.255.255.0"
		puts "allow admin:$password"
		puts $COMMON_CONFIG_2

                puts $MULE_CONFIG
		puts "	check process ssh with pidfile /var/run/sshd.pid"
		puts "	 start program  \"/etc/init.d/ssh start\""
		puts "	 stop program  \"/etc/init.d/ssh stop\""
		puts "	if failed port 22 protocol ssh then restart"
		puts "	if 50 restarts within 50 cycles then timeout"
		puts "	check filesystem data with path /dev/sda3"
		puts "	 start program  = \"/bin/mount /data\""
		puts "	 stop program  = \"/bin/umount /data\""
		puts "	if failed permission 0660 then unmonitor"
		puts "	if failed uid 0 then unmonitor"
		puts "	if failed gid 6 then unmonitor"
		puts "	if space usage > 60% for 5 times within 15 cycles then alert"
		puts "	if space usage > 80% for 5 times within 15 cycles then alert"
		puts "	if space usage > 99% then stop"
		puts "	if inode usage > 90000 then alert"
		puts "	if inode usage > 99% then stop"
		puts "	group server"
		}
}

